==> okteta-0.25.2.tar.xz: okteta-0.25.2/libs/kasten/core/io/abstractexportjob.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008-2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "abstractexportjob.h"
#include "abstractexportjob_p.h"

namespace Kasten {

AbstractExportJob::AbstractExportJob(AbstractExportJobPrivate* d)
    : d_ptr(d)
{}

AbstractExportJob::AbstractExportJob()
    : d_ptr(new AbstractExportJobPrivate(this))
{}

AbstractExportJob::~AbstractExportJob()
{
    delete d_ptr;
}

AbstractDocument* AbstractExportJob::document() const
{
    Q_D(const AbstractExportJob);

    return d->document();
}

void AbstractExportJob::setDocument(AbstractDocument* document)
{
    Q_D(AbstractExportJob);

    d->setDocument(document);
}

}

==> okteta_0.26.3.orig.tar.xz: okteta-0.26.3/libs/kasten/core/io/abstractexportjob.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008-2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "abstractexportjob.hpp"
#include "abstractexportjob_p.hpp"

namespace Kasten {

AbstractExportJob::AbstractExportJob(AbstractExportJobPrivate* d)
    : d_ptr(d)
{}

AbstractExportJob::AbstractExportJob()
    : d_ptr(new AbstractExportJobPrivate(this))
{}

AbstractExportJob::~AbstractExportJob() = default;

AbstractDocument* AbstractExportJob::document() const
{
    Q_D(const AbstractExportJob);

    return d->document();
}

void AbstractExportJob::setDocument(AbstractDocument* document)
{
    Q_D(AbstractExportJob);

    d->setDocument(document);
}

}
